# Verkada_py

![Python Checking](https://github.com/Cyb3r-Jak3/Verkada_py/workflows/Python%20Checking/badge.svg) [![Documentation Status](https://readthedocs.org/projects/verkada_py/badge/?version=latest)](https://verkada_py.docs.jwhite.network/en/latest/?badge=latest)  
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/verkada_py) ![PyPI](https://img.shields.io/pypi/v/verkada_py)


An unofficial Verkada API Python Library. Useful for individuals or companies looking to easily and pragmatically interact with their Verkada cameras. The goal of this library is to make it easier for developers to interact with Verkada's API.
Read the documentation here: https://verkada-py.docs.jwhite.network

Read Verkada's REST API's Documentation here: https://apidocs.verkada.com.
